/*
* file CcLockInfo.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcLockInfo
*
*  Copyright IBM Corporation 2007, 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import java.util.Date;
import java.util.List;


/**
 * Locks can be set on most Clearcase objects.  CcLockInfo
 * is an object that holds the properties that a lock
 * can have.  Note that two of the properties: LockedByUser
 * and LockedOnDate, are set by Clearcase, so only getters
 * are available in this interface.
 */
public interface CcLockInfo {
    
    /** 
     * Get the name of the user who set the lock.
     * @return String containing the name of the locking user.
     */
    public String getLockedByUser();
    
    /** 
     * Get list of excluded users. 
     * @return List of user names to whom the lock does not apply. 
     */
    public List<String> getExcludedUserList();
    
    /** 
     * Set the list of excluded users.
     * If providing an excluded user list, obsolete may not be set <code>true</code>. 
     * @param nusers List of user names to whom the lock does not apply
     */
    public void setExcludedUserList(List<String> nusers);
    
    /** 
     * Get the description of the lock.  This is not symmetric
     * with the input to setLockDescription, because Clearcase
     * adds its own information to the description.
     * @return String containing the lock description. 
     */
    public String getLockDescription();
     
    /** 
     * Set the description of the lock.
     * @param description Comment to be applied/displayed with the lock. 
     */
    public void setLockDescription(String description);
    
    /** 
     * Get the date object was locked.
     * @return Date the lock was applied. 
     */
    public Date getLockedOnDate();
    
    /**
     * Check if this is an obsolete lock (should be hidden from most operations).
     * @return <code>true</code> if the lock is obsolete, <code>false</code> otherwise
     */
    public boolean getObsolete();
    
    /**
     * Set the obsolete state of the lock.  If not specified, default is <code>false</code>.
     * If setting obsolete to <code>true</code>, an excluded user list may not be provided. 
     * @param obsolete <code>true</code> if the lock is obsolete, <code>false</code> otherwise
     */
    public void setObsolete(boolean obsolete);
    
}
